All language subtitles for Revival 2025 S01E09 Mother of bblon 1080p CRAV WEB-DL DD5 1 H264-STC[EZTVx.to]_Legendas01.ENG

af Afrikaans
ak Akan
sq Albanian
am Amharic
hy Armenian
az Azerbaijani
eu Basque
be Belarusian
bem Bemba
bn Bengali
bh Bihari
bs Bosnian
br Breton
km Cambodian
ca Catalan
ceb Cebuano
chr Cherokee
ny Chichewa
zh-CN Chinese (Simplified)
zh-TW Chinese (Traditional)
co Corsican
hr Croatian
cs Czech
da Danish
en English
eo Esperanto
et Estonian
ee Ewe
fo Faroese
tl Filipino
fi Finnish
fr French
fy Frisian
gaa Ga
gl Galician
ka Georgian
el Greek
gn Guarani
gu Gujarati
ht Haitian Creole
ha Hausa
haw Hawaiian
iw Hebrew
hi Hindi
hmn Hmong
hu Hungarian
is Icelandic
ig Igbo
id Indonesian
ia Interlingua
ga Irish
it Italian
ja Japanese
jw Javanese
kn Kannada
kk Kazakh
rw Kinyarwanda
rn Kirundi
kg Kongo
ko Korean
kri Krio (Sierra Leone)
ku Kurdish
ckb Kurdish (Soranรฎ)
ky Kyrgyz
lo Laothian
la Latin
lv Latvian
ln Lingala
lt Lithuanian
loz Lozi
lg Luganda
ach Luo
lb Luxembourgish
mk Macedonian
mg Malagasy
ms Malay
ml Malayalam
mt Maltese
mi Maori
mr Marathi
mfe Mauritian Creole
mo Moldavian
mn Mongolian
my Myanmar (Burmese)
sr-ME Montenegrin
ne Nepali
pcm Nigerian Pidgin
nso Northern Sotho
no Norwegian
nn Norwegian (Nynorsk)
oc Occitan
or Oriya
om Oromo
ps Pashto
fa Persian
pl Polish
pt-BR Portuguese (Brazil) Download
pt Portuguese (Portugal)
pa Punjabi
qu Quechua
rm Romansh
nyn Runyakitara
ru Russian
sm Samoan
gd Scots Gaelic
sr Serbian
sh Serbo-Croatian
st Sesotho
tn Setswana
crs Seychellois Creole
sn Shona
sd Sindhi
si Sinhalese
sk Slovak
sl Slovenian
so Somali
es-419 Spanish (Latin American)
su Sundanese
sw Swahili
sv Swedish
tg Tajik
ta Tamil
tt Tatar
te Telugu
th Thai
ti Tigrinya
to Tonga
lua Tshiluba
tum Tumbuka
tr Turkish
tk Turkmen
tw Twi
ug Uighur
uk Ukrainian
ur Urdu
uz Uzbek
vi Vietnamese
cy Welsh
wo Wolof
xh Xhosa
yi Yiddish
yo Yoruba
zu Zulu

Original subtitles

-[inspirational fanfare]

-RHODEY: Previously on Revival.

-I lost my mom and it was an awful accident.

-KEN: Take your hands off her! -No! Ken!

-It's amazing what people will share

when you promise them safety.

-Rose is special to me.

-You're giving him snake venom?

-CARLA: It dramatically slows down reviver healing.

-Moore Creek. -WANDA: Please.

I never ever hurt anyone.

-What was that, Mr. Abel?

-That is how we are going to cleanse Wausau.

-[Ibrahim cries out]

-DANA: Where is he? Where's Ibrahim?

-Back at Moore Creek. I couldn't bring him with me.

-I'm so sorry, Em.

-[whoosh] -[Em sharply gasps]

-[score fades out]

-[electrical buzz]

-[quiet tense score]

-[Ibrahim whimpers]

-[whimpers turn fearful, frantic and loud]

-[chair legs clatter]

-[chair thuds]

-[rumbling]

-[Ibrahim stops whimpering]

โ™ชโ™ชโ™ช

-[Ibrahim moans]

-Help! -[whimpers loudly, repeatedly]

-[Blaine growls menacingly]

-You're awake.

Lovely.

-[ethereal opening theme]

-[ringing whoosh]

-[ringing whoosh] -[pistol uncocking]

-[Ibrahim resumes whimpering]

Here. Here, here.

-[Ibrahim yells, moans in pain]

There you go.

You're lucky my men were scouring that area.

-I heard all about you, preacher.

-[groans] Should have just...

You should have just left me at the creek where you found me.

-For the soldiers to find you?

In the state you're in? No, no, no. You're the

great doctor, after all.

-[rapid nervous breathing]

He who studies revivers.

I read your notes and, uh,

you're hiding something, Doctor.

Why don't you tell me what started Revival Day.

We can help each other.

-Don't you already have all the answers?

Huh?

Or are you just pretending for all your followers?

-I have some pieces.

But I want to know the origins of the evil, right?

So I can better fight it.

You know, ensure it never happens again.

-You are a hate-monger.

I'm not helping you.

-[breathes erratically from fear]

-You know, on Revival Night

I was called to tow a car.

-[dramatic boom]

And then I felt this blast of energy

come through the forest and I saw a light

shine from the sky and I ran to that light

to find the origin, but it was already too late.

You know why? -[dramatic boom]

The gates of Hell had opened.

The demons were free.

-Hm.

Bet you've been waiting a long time

for something like this to happen, huh?

Huh? So you could continue to do your little radio show,

stoking fear and hate, huh?

Pretending to be chosen by God.

-Shame on you.

No, people may think a lot of different things about me,

but one thing I am not is a fraud.

And I'm going to prove it.

-You actually...

You actually believe what you're selling, huh?

-Maybe you should, too.

-[loud bang] -[locker door hinges squeak]

-The last thing you want is to turn Blaine

into a martyr for his cause.

-He's killed your girlfriend and my sister

and now she's missing and I know he has her.

-[clip slams loudly] Martyr's still dead...

-[chambers round loudly] and that's good enough for me.

-We have the element of surprise so let's use it.

-MAY: And the general? -We approach from the woods.

-She doesn't care about us. -We take out the guards.

Quietly, individually. -DANA: She just wants Em.

-JP: Then we go after Blaine.

-[clip snaps into firearm] -Good.

JP is right. So listen up:

We need to be smart and tactical about this, right?

I want this son of a bitch as much as anybody, but, uh,

we don't want to start a full-blown war with his militia.

-[racks rifle] -[dramatic score]

Let's do it. -[locker door hinges squeak]

-[score fades out]

-So when did you lose your faith, Dr. Ramin?

-I haven't.

I just don't let it cloud my reason.

-My angel would have opened your heart.

-Your angel?

-I lost her but she'll come back to me.

Through the woods, like she did last time,

just a beacon of light.

-A yellow light?

Did your, um, did your angel call out with a,

a pained moaning sound, too?

-[soft tap]

-I think I've said enough.

It's your turn to share.

-I'm not helping you hurt them, Blaine.

-You know we want the same thing, Doctor.

-[quiet intriguing score]

I can see it in your eyes. The same fire I have in mine.

To know. To understand.

We came here for a reason.

-[Ibrahim sighs]

- Kullu nafsin dha'iqatul mawt.

-[score turns darker]

Every soul shall taste death.

-[loud bang] -WAYNE: Police!

Keep your hands where I can see them, Blaine.

-BLAINE: Ah, yeah. -WAYNE: Stand up slowly.

-[police radio chatter] -It's okay.

-DANA: Why are you here? -WAYNE: Move over there.

-FITZY: Yeah, yeah. I got him. -WAYNE: Fitzy! Cuff him.

-(whisper) Where's Em? -FITZY: Pat him down.

-I don't know. -[distant approaching sirens]

-Fitzy: He's clear. -[indistinct police chatter]

-CARLA: Why does she require such extreme measures?

-CALE: She needs triple the dose.

Her body heals faster.

She fights back when others don't.

And she's demonstrated an unmatched threshold

for violence. Doctor, the clock is ticking

and I must account for control and remove all the revivers.

I'll find the revivers,

but I need you for the control part.

-She's experiencing some form of hysterical psychosis.

She's not fit to be moved.

-So fix her. -[loud buzzer]

-PATTY (muffled): Martha. Martha.

(normal) Martha.

-[score fades out] -[ventilation system hums]

You're going to be okay.

-Mom?

-[dramatic score]

-[distant cacophony of voices] -[score fades out]

Lester Majak asked me to tow a car.

-A car rented by Aaron Weimar, who you then had killed.

-Okay, so, hypothetically,

let me indulge here with this theory.

So, what would I have to pay Deputy Brent

to kill the professor?

-You paid $10,000. -(laughing) Ha!

Ten thousand dollars?! Yeah?

And does it look like I have $10,000?

I mean, I am a tow truck driver living in a junkyard, so...

-[sarcastic sound] -You had enough money

to try and buy your father's land back from Blackdeer.

-You see, I gave that away before your sister was killed.

-Wow! Who'd you give it to?

-That's my business

and only God can judge me. -Oh, I'm so sick of this

Chosen One bullshit.

-You know,

when I saw your sister on the bridge that night,

cold, alone, -[quiet tense score]

messed up,

I couldn't help but wonder

who in her family failed her so miserably

that she ended up a murdered junkie.

Hm?

You? You?

-WAYNE: I can't imagine how you must have felt

losing everything,

so publicly, so shamefully.

And then to have your mother run out on you

immediately thereafter.

And then your father gets killed.

-So, then you find these two young, innocent women,

with their whole lives ahead of them and you...

you're just angry and you just want to punish them.

-WAYNE: So you get Aaron Weimar to find them,

befriend them, lure them into the woods

so that you're not seen with them

the night they're murdered.

-And you decide to play God and use them

to fulfil your sick fantasy of being chosen.

-No. -That's why you murdered Rose

and my sister! -No.

-I did not murder your sister. Okay?

And I did not murder Rose!

She was my friend.

-You know, we finally found her body.

In the trunk of one of the wrecked cars on your lot.

-That's bullshit! That's bullshit!

You reviver lovers, just setting me up.

You just want to destroy me like you did my father.

-I would've left your father alone, Blaine,

except he was swindling people out of their life savings,

conning them into believing you had stigmata

by sticking nails in your hands.

-This was my father preparing me for the day I was chosen.

-You know what? We don't need your confession.

We know what you did and we know why you did it.

I just hope to hell your redneck militia

can handle the news that you're a fraud

'cause your father's flock sure as hell couldn't.

-Please.

-[score fades out]

-He truly believes he's been chosen by God,

so how does murdering Rose and Em help his mission?

-He was probably offering them as sacrifices

to prove how worthy he was of being chosen.

-Yeah, but why team up with a Humanities professor to do that?

If it was to keep his hands clean,

why would he choose Rose,

someone he had a direct connection to?

-You auditioning to be his defence attorney?

-No. No. No, he's-he's crazy. Sure.

But he's curious.

His threats are only directed towards revivers,

not young women,

so I'm just struggling to find a motive that fits.

-Is he in there? -[quiet tense score]

-Yeah, yeah. It's okay. We got him.

Listen,

I need your help. -[May scoffs]

You're a better investigator than most of our deputies.

-Most?

-Find out where Blaine's money went.

-[indistinct PA announcement]

-[distant buzzer blares] -[door hinges squeak loudly]

-[distant man screaming]

-SOLDIER: Hurry up.

-[door hinges squeak loudly] -[door slams closed]

-Hey, Em. It's me, Rhodey.

They said you were sick and

I wanted to see you, make sure you're okay.

-So this is the boy you've been seeing?

What's he like?

-Em, I...

I never meant for this to happen.

They threatened my family.

They tortured me.

And...

I wasn't strong enough.

-[Patty groans]

-There's one thing I've learned in my day:

men will say anything to get you to take them back,

but as soon as you do they will break your heart

all over again.

I have to wonder, Martha,

what made you choose a boy

who could do something like this to you?

-You think you'll ever be able to forgive me?

-You don't need him, lovebug.

You have me now.

-[score intensifies]

-[score abates] -[collar rattles]

-[quiet emotional breaths through nose]

-Hm.

-[snap] -[dramatic percussive score]

-[bones cracking]

-[Rhodey coughs] -Let me out!

Please! She's not okay!

-Please don't leave me again.

-I don't know what else to tell you.

Just get her under control.

-There's a problem at security.

-[distant man yells]

Some old reviver-loving townie causing trouble.

-Deal with it! And set an example.

-The sooner we get them to Ember Point, the better.

-Uh, Ember Point?

-Above your pay grade, Doctor.

-(whisper) Ken, you have to get me out of here.

This place is awful. -[breathy inhale]

They're doing something to the other revivers.

All day long it's just screaming.

-They done anything to you?

-No, they haven't touched me.

But I am so afraid at any moment they're going to.

I can't stand it.

-They won't, they won't. I promise.

We made a deal.

-[inhale] -A deal?

-Mm-hm. -[loud distant buzzer]

It's complicated.

-Remember,

we made a promise to each other.

No more secrets.

-The general asked me to identify a reviver

(whisper) on a surveillance video.

It was Martha Cypress. -[dramatic boom; rumbling]

-You're the reason they caught Martha?

Oh, Ken.

She's a child.

-(whisper) I know. I know, I know.

-Listen, listen...

(whisper) I heard the general talk to a soldier.

I think they want to move us.

-Move?

Wait a second.

I saw all these transport trucks and, uh,

shipping containers outside that weren't there before.

She's getting ready to do something. And soon.

I promise I'll get you out of here, okay?

Hey, don't worry. -[distant indistinct voices]

-Well, if Ibrahim is right, then we're back at square one.

I mean anybody in Wausau

could've killed Rose and your sister.

-Believe me, I know. -[score fades out]

Do we have any whiskey for this coffee?

-[office phone rings]

-Look, we have a guy in lockup right now

who had the means, opportunity

and pathology to commit these murders.

-I'm not saying we should let Blaine go.

I'm just saying we need to be sure.

Otherwise, Em and every other young woman

in Wausau's not safe.

-All right.

We hang on to him as long as we can.

We continue to investigate until we find evidence that

points one way or the other, but my money's on Blaine.

-KEN: Wayne! -WAYNE: You son of a bitch.

-[Dana grunts] -KEN: Oh! Oh!

-That's for narcing on my sister!

-I tried to stop him. -Thanks, Fitzy. It's okay.

-KEN: Oh. -What the hell do you want?

-[quiet tense score] -I deserve that.

But you gotta listen.

The general found Martha.

-What? How? -Where?

-We got bigger problems.

Diane overheard the general talking.

They're moving all the revivers, including Martha.

We gotta bust them out, or we'll never see them again.

because it has the best tactical security

of any of the empty facilities in Wausau.

It has a single entrance

leading to a set of stairs down into the basement.

-It's a choke point.

-It's the only way to save Em.

-How does us getting blasted to pieces help your sister?

-How does sitting on our asses save her?

-Focus, please!

All right, if the general is planning a mass move

of revivers, she's not going to take any chances.

So, JP, call Paul Blake at the department of transportation.

Tell him that I need to know if they've cleared any highways,

rail lines, or flight paths out of Wausau.

-All right. You got it, chief. Let's go.

-WOMAN: Hey, Sheriff! I need a hand here!

-They're nothing but cowards!

Nothing but bullies hiding behind army fatigues.

I've seen it a hundred times.

-What happened? -What's going on?

-He went to Riverside to find his friend

and they pistol whipped him and then dumped him near my bar!

-So much death and destruction and what do we have

to show for it? It's the reason I left the army

to focus on life instead of death!

-Lester, calm down. You're going to give yourself a coronary.

-Wanda didn't ask to come back from the dead,

but she was doing the best that she could.

Even after losing her social security.

I did what I could to help her,

but you couldn't care less, Sheriff!

You all overlook us because of our age!

-[quiet tender score]

We still have good years ahead of us!

Oh. -Uh, let me get you some ice

for that eye.

-Don't bother. It's a badge of honour.

-See if you can convince him to go to the hospital.

That looks nasty. He needs to get checked out.

-No, no, no. That is the cost

for standing up for the people in this town.

Something that you couldn't be bothered to do

until you realized that Martha was one of them.

That's not leadership. That's cowardice.

Just like the man that did that to Lester.

Any revivers get free, you send them to me.

I can get them out of Wausau

through the old bootlegging tunnels under the bar.

-[keyboard clacking]

-Okay, so Blaine was telling the truth.

He gave away his money.

-To who? -To you.

Well, originally, to the department

as a reward for finding Rose's killer.

-Wait, Blaine was behind the anonymous reward for Rose?

That was-- -Fifty thousand dollars. Yeah.

-Well, we never got that money. They pulled it when Jesse ran.

-Then it went to the Missing and Murdered

Indigenous Women's Fund.

-I guess he could've donated it out of guilt.

I don't think he did.

-Dana, he can't go free.

You have to find something to make this stick.

Finish what you started.

-[score fades out]

I'm taking off. -Ah.

-[Ibrahim sighs]

-Hey, I'm a journalist.

I'll take my info from any reliable source.

-Yeah, well, I'm a scientist. I shouldn't be

looking for answers in religious texts.

-Says who?

The dead have risen, Doc. Pretty sure there are no rules.

You know, Rose and I always used to say

that whoever died first would come back

and haunt the other. -Hm.

-Just to prove there was an afterlife.

-Like, uh, Harry Houdini and his mother.

-Exactly.

-Have you, have you heard from her?

-Not yet.

But I'm keeping my fingers crossed. [laughs]

-[office phone rings]

Good luck with your soul-searching.

-[dot-matrix printer whining] -Hm.

-[dramatic boom] -[indistinct chatter]

-[quiet tense score] -[chatter over police radio]

-[rattling]

-Dana, I don't even know what I'm looking for here.

It's all just his plans for storming the gates of Riverside.

And it's not too hot of a plan, if you ask me.

-There must be something here about Rose, or my sister.

Oh.

-[loud banging]

-Oh. He wouldn't be the first murderer

to record his crimes.

-[clattering]

-WANDA: Get it away from me.

-[Wanda screams]

-[creature bellows loudly]

This isn't mine.

This isn't mine.

-[loud bellowing continues]

-[Wanda screams]

-Jesus.

So that's how Wanda Peterson died.

-He's found a way to kill revivers.

-Seems like that light is the thing that killed her.

-No. No, it's--

I've seen the source of light. It's a creature, or a being.

Tall, thin, like, -[quiet tense score]

like an apparition, but it wouldn't kill.

-What are you saying? Like an alien?

-I don't know, Sheriff, I don't know.

But I saw it touch Cooper's friend, Jordan,

and that's not what happened. She went toward it peacefully

and then she just, she disappeared.

-Yeah, that's what Cooper said, but it doesn't make sense

'cause if what happened to Wanda is what happened to Jordan--

-It's not, Dana. Trust me.

-People just don't disappear, Doctor.

-And that's not what happened in that video.

-Well, maybe the thing that you saw

is different from the thing in the video?

-Maybe. Certainly had a presence.

Something beyond words. I...

-You're supposed to be giving us answers,

not add aliens to the mix.

-I know, I know, I know.

And don't you think I feel like I've failed you all every day.

That maybe Em and Diane and Wanda would all be safe

if I just figured out what happened on Revival Day?

That maybe you'd all be better off

if I hadn't insisted on heading the CDC efforts here in Wausau?

-Well, regardless,

clock is ticking and we now have two problems.

-Blaine's going to break into Riverside.

He wants to use that thing to kill all the revivers.

-He called it his angel, but he told me he lost it.

-Well, that sounds like a good thing, doesn't it?

-I know what the general's up to.

-[paper crinkling]

Tomorrow at 1700 hours

the Department of Transportation has shut down a lane

of Highway 51 North to Fox Valley rail line.

There's a defunct line

that goes all the way to the docks at Lake Superior.

-So, she's going to truck the revivers to a rail line

and put them on a ship to Christ knows where.

-Diane had mentioned to me that she had the suspicion

that they were going to move the revivers and soon.

-And now that we know what she's up to,

all we need to do is stop her.

-No.

We force her into a new plan.

One that works for us.

-[score crescendos, fades out]

-[very distant buzzer blares]

-[buzzer blares loudly] -[door unlocks loudly]

-[door hinges squeak]

-Hello, Martha.

I understand you're having a difficult time right now.

-Now who do we have here?

-I'm just here to talk.

I won't touch you, or hurt you.

-Have an affair with a married man

while his wife was going through cancer treatment.

Martha, I raised you better than that.

-I'm sorry. I'm so...

-[Em inhales shakily] ...so sorry.

-Can you tell me what's going on around you?

-Maybe that's why you were murdered.

As punishment for ruining the home life

of a sick, fragile woman. -Don't say that.

-It's a good thing I died in that crash.

If I'd lived long enough to see you turned into a home-wrecker,

I might've killed myself. -Mom!

-Patricia Cypress.

But everyone called her Patty, right?

-[Em cries softly]

-Can you see her too?

-Martha, is your mother in the room?

-Yeah.

-You're experiencing a break with reality.

Likely it's stress-induced.

But, look,

I'm here to help you, okay?

-Do you know what happened to her?

-No.

Would you like to tell me?

-[tremulous inhale, exhale]

-Dana got into a fight at Nella's bar because

some townie was heckling her for the Blackdeer case and--

-Stop it, Martha! That story is for our family.

-Then... -Just our family.

-And my mom called my dad

because she didn't like to drive in winter,

but he didn't pick up. -Stop it!

-Martha, look at me. Talk to me, okay?

-So I drove. -Martha, stop.

-And when I was driving-- -No.

-A deer just-- -No!

-Came out of nowhere. -NOOO!

-It was all my fault! -[loud bangs]

And it was all my fault!

It was all my fault!

I'm so sorry, Mom. -SOLDIER: Time's up.

-What do you mean? She's in a state of distress.

-She's coherent enough to follow directions.

-She's still in a very fragile-- -That's all I need.

-[loud bang] -Martha, no!

No! Martha! This isn't you.

-[dramatic score]

Martha... -[soldier chokes]

I know that you've felt so much loss in your life,

but this will only make those feelings worse.

Please.

Let him go.

-[Em pants]

-[clattering]

-[pistol clatters loudly on floor]

-[door bangs loudly] -[loud buzzer]

-See, Mom?

I am the Martha you raised.

I did the right thing.

-[dramatic boom] -[quiet tender score]

-[restraint collar rattles]

Mom?

-General Cale!

I have an urgent message for General Cale.

-[cage rattles] -Whoa, whoa.

-There's a local militia--

There's a local militia that's going to attack

Riverside tomorrow! -SOLDIER: We got it.

-And they've found a way to kill revivers!

-Get out of here. Go! -Listen to what I'm saying!

They're going to kill revivers.

-[sniffles]

-[Carla gasps]

-Carla.

-Ibrahim. Where have you been?

-I need you to tell me what time the general

is planning on moving the revivers.

-[Carla sighs] -I don't want to get involved.

-You're already involved.

-This is not what we came here to do.

-I know. That's why I'm trying to make it right

and why I'm giving you a chance to make it right.

-[Carla sighs]

-She heard about Blaine's plan.

She's moving them at sunrise. And, Ibrahim,

they're moving them to some secret facility.

-No, they're not. -[zipper unzips]

-[plastic crinkling]

I need you to give the revivers this.

-[plastic crinkling] -What's in these vials?

-It's just water. -[dramatic percussive score]

-[car door closes] -[clip snapping]

-[loud snap] -[score abates]

-If we can pull this off, JP and Nella are gonna need

all the help they can get getting over the border,

so, here you go.

Always aim for centre mass.

-Y'know, when I became a doctor I never imagined I'd be

solving murders and planning extractions.

-Listen,

you saved my sister's life, so,

that may not be why you came here but,

to me, it's what matters most.

-Thanks. Uh...

-WAYNE: Okay, so... -I'll be at Nella's.

-[bag bangs onto desk] -Yeah.

-This is all the pyro we have at the station, okay?

So we're going to use the woods and the cover of night

to get set up outside.

JP and Rogers will set up on the north perimeter.

They're going to set all this off at once

so the general thinks Blaine's militia is attacking.

Dana, you, Ken and I will be on the other side.

We're going to enter from the back lot,

take care of business.

Look, I know I screwed up when it came to protecting this town

and I own that.

This is my chance to make it right.

So, let's do it, uh?

Let's go save the people that we love.

-[score crescendos, fades out]

-[creek loudly burbling] -FOLLOWER: All right, I'm on it.

-[quiet tense score] -[bird chirping]

-[loud burbling] -[high-pitched ringing]

The angel! Look!

-FOLLOWER 2: Yeah, yeah. -See, Mr. Abel was right.

Another one's coming. -[loud high-pitched ringing]

Man your stations!

-[creature moans loudly]

It's beautiful. -[gunshot]

-[follower grunts, groans]

-[metallic clicks, snaps ejecting and loading rounds]

-[score intensifies] -[loud gunshot]

-MAN: Whoa! -[creature trumpets loudly]

-[loud gunshot] -[follower cries out]

-[score fades out]

-Oh. -I, uh, I brought you this.

-Oh. -A sandwich.

-[quiet tense score] -Thank you. That's...

That's kind. I kind of assumed everyone had just left me here.

-Yeah, well, uh, I have more questions for you, Blaine.

Um... -Okay.

-You said that, uh, on the night of Revival Night,

that Lester Majak called you to tow a car

the same night you saw that yellow light

shoot up into the sky and the same night

that you saw Em Cypress on the bridge.

-I saw Em on the bridge before.

Right? I went to tow the car,

I saw the light... -Yes.

-...and then when I went back, the light was gone,

but Em was no longer on the bridge. Just her stuff.

-Em wasn't at the bridge.

Em Cypress was not there

when the yellow light shot up into the sky.

You see, I've been studying that water at Moore Creek.

It has special properties specifically designed to

heal revivers. It helps revivers,

specifically Em Cypress. I've literally seen it

bring her back to life and if that's the case,

if Em Cypress is connected to the water,

that means that she was murdered.

Which means that

Em's death caused Revival Day.

-She what? -Oh!

-I'm sorry, brother, okay? -Hey.

-This is for the greater good. -Hey, hey, hey, hey.

-Okay? -Yeah.

-All right, now, hey! I'm walking out of here!

No! Go back! Anyone moves, the doctor dies.

-[door bangs, hinges squeak] -SOLDIER: Rise and shine.

-[score abates]

-[cart wheels clattering]

You're taking your medicine early today

because we're going on a little field trip.

-I'm not going anywhere

or taking anything until I can see Em Cypress

and make sure she's okay. -[ratcheting]

-[soldier scoffs] -So now you're in charge?

-[pistol cocking] -Hey, hey! Back off.

Let me talk to him.

I said I got this. Give us some space.

-[pistol uncocks]

-[distant prisoner screams]

This is going to feel different, but you have to act the same.

Okay? -[distant banging echoes]

It's the only way to save Em.

-SOLDIER: Hurry up!

-Now, you're going to behave, right?

(whispers) Help is coming. Spread the word.

-[scraping; click] -[hiss]

-[Rhodey loudly groans]

-[tense score]

-[dramatic boom] -[sharp inhale, loud exhale]

-[calming exhale]

-SOLDIER: All right, you know the drill! Let's go!

Single file, no talking, as you were told.

-MALE: Where are they taking us? What are they going to do?

-(whisper) We're taking out the guards at my cue. Pass it.

-We're going to take them. Wait for my cue.

-SOLDIER: Up the ramp. Around the corner.

Up the ramp, in the truck. Move.

Single file.

Let's go, let's go. -[loud distant explosions]

What the hell? -[prisoners react in confusion]

Everybody in the truck! Get 'em in the truck!

Hey! You two! Go set up an observation point. Now!

Command, this is Alpha 2. Priority red.

I repeat: priority red.

We have an incoming hostile force.

Small militia approaching from the northeast. Over.

Let's go! Move!

-[loud bangs] -[door hinges squeal loudly]

-[indistinct radio chatter]

-[prisoner groans] -[loud bang]

-RHODEY: Now! Fight! -[revivers yell encouragements]

-Go! Go! Get 'em! Yes. -[exciting percussive score]

-[click] -[muffled yelling]

-You so much as twitch

and your skull is gonna have a skylight.

-[feet clang on metal stairs]

-[clattering]

-[dramatic score]

-[loud buzzer] -[door lock disengages]

-Who are you?

-Your sister sent me.

We have to go now. The guards are coming.

-[rapid high-pitched beeping] -[mechanical lock disengages]

-[door hinges squeak]

-[distant people yelling]

Come on.

-Where's Em?

-She's not here. She's still inside.

-We gotta go back in and get her!

-No time! They're coming out the door any second!

-We can't just leave her here!

-We need to figure out how to get her out of there.

-Oh, no, no, no, no, no.

We're getting the hell out of here. Let's go.

-Dillisch! Where the hell are you going?

The only reason she's in there is because of you!

-You're the one who called the governor.

-[quiet tense score] -Ken.

-You're the one who had my wife locked up.

You're the one who put all this

shit in motion, Wayne, not me.

-No, Dad! Jesus Christ! You two were best friends

and now you're at each other's throats when

we need each other the most. What the hell happened?!

-What the hell happened

is that Wayne Cypress is a goddamn home wrecker.

-DIANE: Ken, please.

-When Patty died,

ask him why he missed the call from Nella at the bar.

Why he didn't come and pick you up.

Ask him where he was!

-I'm so sorry, Dana.

Dana.

-Save it for your memoir.

-Guys, we need to move now! We gotta go!

-Get the revivers to Nella's bar.

-What about Em? I can't leave here without her.

-[Wayne continues directing] -I will take care of Em.

But they need you right now. We need your help. Go.

Go!

-Dana. -No!

Not now. -SOLDIER: Clear!

-We gotta go! We gotta go!

-[score intensifies] -[explosion]

-[dramatic militaristic score]

-[dramatic boom] -[score fades out]

-[car door opening]

-[car doors close]

Look, Dana, your mother and I were separated.

-I don't want to-- I don't want-- Just, mm-mm.

-[cell phone rings, vibrates]

-[cell phone clatters]

-[Dana inhales, exhales]

How could you not tell me?

-Yeah, what would the point have been?

-[Dana scoffs] Telling you?

-[Dana splutters]

-I spent the last two years... -[tremulous inhale]

beating myself up about Mom.

Em has spent the last two years

blaming herself for the accident and you wanna know the po--?

-[sharp inhale]

-[distant bird calling]

-[Dana sobs] -Honey, me being with Diane

did not cause a deer to run in front of you.

-Should've been you.

-[quiet tense score]

-[cell phone rings]

Who the hell keeps calling? -[score fades out]

-It's Lester.

-We need to focus on finding Em.

-[quiet tense score]

We need a plan. -[sighs]

JP and Nella are at the,

at the border getting revivers out and, um,

Cale will be monitoring comms so even if I knew who

I could trust anymore,

we can't call them. So what do we do?

-[Dana sighs] -[cell phone rings]

Well, just answer it. Answer it.

-You just said the general will be monitoring our comms.

-Lester's just calling to whine about something.

Who gives a shit?

-What do you want, Lester?

-Well, sure.

Now, I'm just minding my own business

out in this nice brisk air on my own property,

and wouldn't you know it, we got some trespassers

that need taking care of.

-Trespassers? Really? I don't have time for this.

-No, no, no, sir. No, this isn't just someone

wandering around.

-[distant dog barking]

They have guns!

I think they might be domestic terrorists.

-Then call the station.

-I already called them.

-Well, then I'm sure they're on it, okay? Goodbye.

-No, no, no! Don't hang up!

They have a girl!

-[dramatic score] -What do you mean a girl?

-I don't know, but they keep saying something about

the girl and what do with the girl and...

-Where are you?

-I'm out on Route 13, by the old church.

-Stay put. We're on our way.

-Where are we going? -[phone clatters]

-The old Abel church. -Blaine has Em?

-Don't know, but we better get there before the general.

-[car engine turns over] -[engine revs]

-[tense dramatic score]

-Where are we?

Ibrahim? What is...

going on?

-BLAINE: Behold!

-[dramatic boom]

Martha Cypress,

you are the Mother of Babylon,

the serpent who opened the gates of Hell.

-[Lucifer by Charles Brady plays]

And I

aim to send you right back.

โ™ช WHOO! โ™ช

โ™ช I know Lucifer โ™ช

โ™ช Was in heaven โ™ช

โ™ช Was in heaven โ™ช

โ™ช I know Lucifer โ™ช

โ™ช Was in heaven โ™ช

โ™ช WHOO! โ™ช

Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.